==> vue3-components-0.1.9.tgz: package/es/form/src/form.js <==
import { defineComponent as N, computed as $, ref as O, shallowRef as _, onMounted as q, watch as z, createVNode as n, resolveComponent as w, mergeProps as p, toRef as G, unref as D, Fragment as H, nextTick as K, isVNode as J } from "vue";
import { formProps as Q, formEmits as W } from "./props.js";
import { dialogProps as X, dialogEmits as Y, ElFormItem as F, ElCol as S } from "element-plus";
import { pickObjByKeys as m, firstUppercase as Z, deepClone as ee, omitObjByKeys as oe } from "@tomiaa/utils";
import { KCustomElement as v } from "../../customElement/index.js";
import { Toolbar as le, Editor as te } from "@wangeditor/editor-for-vue";
import "@wangeditor/editor/dist/css/style.css";
function ne(l) {
  return typeof l == "function" || Object.prototype.toString.call(l) === "[object Object]" && !J(l);
}
const pe = N({
  name: "KForm",
  props: Q,
  emits: W,
  setup(l, {
    attrs: g,
    slots: u,
    emit: s,
    expose: U
  }) {
    const b = l.modelValue !== void 0, j = ["", !1].includes(g.inline), x = $(() => m(l, Object.keys(X))), k = {};
    for (const e in Y)
      k["on" + Z(e)] = () => s(e);
    const f = O(), L = () => n(w("el-dialog"), p({
      ref: f
    }, k, {
      "onUpdate:modelValue": (e) => s("update:modelValue", e),
      onClosed: () => {
        var e;
        !l.destroyOnClose || (y(), (e = i.value) == null || e.resetFields());
      }
    }, x.value), {
      footer: l.showActions ? R : void 0,
      ...u,
      default: V
    }), R = () => {
      var o, r, a, M;
      let e = [{
        el: "el-button",
        type: "primary",
        "v-if": l.actionsConfig.showSubmit,
        onClick() {
          var P, T;
          const c = {
            formRef: i,
            dialogRef: f,
            formModel: t,
            validate: (P = i.value) == null ? void 0 : P.validate,
            rawFormModel: h()
          };
          if (l.autoValidateOnSubmit) {
            (T = i.value) == null || T.validate((I) => {
              s(I ? "submit" : "submitCheckFail", c);
            });
            return;
          }
          s("submit", c);
        },
        children: (o = l.actionsConfig.submitText) != null ? o : "\u63D0\u4EA4"
      }, {
        el: "el-button",
        "v-if": l.actionsConfig.showReset,
        onClick() {
          var c;
          i.value.resetFields(), s("reset", {
            formRef: i,
            dialogRef: f,
            formModel: t,
            validate: (c = i.value) == null ? void 0 : c.validate,
            rawFormModel: h()
          });
        },
        children: (r = l.actionsConfig.resetText) != null ? r : "\u91CD\u7F6E"
      }, {
        el: "el-button",
        "v-if": l.actionsConfig.showCancel,
        onClick() {
          s("update:modelValue", !1), s("cancel");
        },
        children: (a = l.actionsConfig.cancelText) != null ? a : "\u53D6\u6D88"
      }];
      return (M = l.actionsConfig) != null && M.custom && (e = l.actionsConfig.custom(e)), b ? n(v, {
        list: e
      }, null) : j ? n(F, null, {
        default: () => [n(v, {
          list: e
        }, null)]
      }) : n(S, l.actionsConfig, {
        default: () => [n(F, null, {
          default: () => [n(v, {
            list: e
          }, null)]
        })]
      });
    }, i = O(), t = O(l.model), y = () => {
      l.options.forEach((e) => {
        if (e.prop && typeof e.prop == "string") {
          const o = e.el === "el-upload" ? "fileList" : "modelValue";
          t.value[e.prop] = G(e, o);
        }
      });
    };
    y();
    const h = () => {
      const e = {};
      for (const o in t.value)
        e[o] = D(t.value[o]);
      return e;
    }, V = () => n(w("el-form"), p(g, {
      ref: i,
      model: t.value
    }), {
      default: () => [n(w("el-row"), g, {
        default: () => [A(l.options), l.showActions && !b && R()]
      })]
    }), A = (e) => e.map((o) => {
      if (o = D(o), Array.isArray(o))
        return A(o);
      o.el === "el-upload" && (o.fileList = t.value[o.prop], o["onUpdate:fileList"] = (a) => {
        Object.prototype.hasOwnProperty.call(t.value, o.prop) && (t.value[o.prop] = a);
      });
      let r = {
        ...m(o, Object.keys(S.props)),
        class: o.class ? `${o.class}__el-col` : "",
        el: "el-col",
        children: {
          ...m(o, Object.keys(F.props)),
          class: o.class ? `${o.class}__el-form-item` : "",
          el: "el-form-item",
          children: o
        }
      };
      return j && (r = r.children), o.el === "editor" && (r.children.children = B(o)), n(v, {
        model: t.value,
        list: r
      }, ne(u) ? u : {
        default: () => [u]
      });
    }), d = _({}), B = (e) => (e.prop && !d.value[e.prop] && (d.value[e.prop] = _()), n(H, null, [n(le, p({
      style: "border-bottom: 1px solid #ccc",
      mode: "default",
      editor: e.prop && d.value[e.prop].value
    }, e.editorAttrs), null), n(te, p({
      style: "height: 300px; width: 100%; overflow-y: hidden",
      mode: "default",
      modelValue: t.value[e.prop],
      "onUpdate:model-value": (o) => {
        Object.prototype.hasOwnProperty.call(t.value, e.prop) && (t.value[e.prop] = o);
      },
      onOnCreated: (o) => {
        e.prop && (d.value[e.prop].value = o);
      }
    }, e.toolbarAttrs), null)])), C = {
      initFormModel: y,
      getRawFormModel: h,
      setFormModel: async (e, {
        includes: o = [...l.options.map((a) => a.prop).filter((a) => a), "id"],
        exclude: r = []
      } = {}) => {
        e = ee(e);
        let a = o != null && o.length ? m(e, o) : e;
        r != null && r.length && (a = oe(a, r)), await K(), Object.assign(t.value, a);
      },
      getFormRef: () => i,
      getDialogRef: () => f,
      formModel: t
    }, E = async () => {
      await K(), Object.assign(C, i.value), Object.assign(C, f.value);
    };
    return q(E), z(() => l.modelValue, E), U(C), () => n("div", null, [b ? L() : V()]);
  }
});
export {
  pe as default
};

==> vue3-components-0.2.0.tgz: package/es/form/src/form.js <==
import { defineComponent as N, computed as $, ref as O, shallowRef as _, onMounted as q, watch as z, createVNode as n, resolveComponent as w, mergeProps as p, toRef as G, unref as D, Fragment as H, nextTick as K, isVNode as J } from "vue";
import { formProps as Q, formEmits as W } from "./props.js";
import { dialogProps as X, dialogEmits as Y, ElFormItem as F, ElCol as S } from "element-plus";
import { pickObjByKeys as v, firstUppercase as Z, deepClone as ee, omitObjByKeys as oe } from "@tomiaa/utils";
import { KCustomElement as m } from "../../customElement/index.js";
import { Toolbar as le, Editor as te } from "@wangeditor/editor-for-vue";
import "@wangeditor/editor/dist/css/style.css";
function ne(l) {
  return typeof l == "function" || Object.prototype.toString.call(l) === "[object Object]" && !J(l);
}
const pe = N({
  name: "KForm",
  props: Q,
  emits: W,
  setup(l, {
    attrs: g,
    slots: u,
    emit: s,
    expose: x
  }) {
    const b = l.modelValue !== void 0, j = ["", !1].includes(g.inline), L = $(() => v(l, Object.keys(X))), k = {};
    for (const e in Y)
      k["on" + Z(e)] = (...o) => s(e, ...o);
    const f = O(), U = () => n(w("el-dialog"), p({
      ref: f
    }, k, {
      onClosed: () => {
        var e;
        !l.destroyOnClose || (y(), (e = i.value) == null || e.resetFields());
      }
    }, L.value), {
      footer: l.showActions ? R : void 0,
      ...u,
      default: A
    }), R = () => {
      var o, r, a, V;
      let e = [{
        el: "el-button",
        type: "primary",
        "v-if": l.actionsConfig.showSubmit,
        onClick() {
          var P, T;
          const c = {
            formRef: i,
            dialogRef: f,
            formModel: t,
            validate: (P = i.value) == null ? void 0 : P.validate,
            rawFormModel: h()
          };
          if (l.autoValidateOnSubmit) {
            (T = i.value) == null || T.validate((I) => {
              s(I ? "submit" : "submitCheckFail", c);
            });
            return;
          }
          s("submit", c);
        },
        children: (o = l.actionsConfig.submitText) != null ? o : "\u63D0\u4EA4"
      }, {
        el: "el-button",
        "v-if": l.actionsConfig.showReset,
        onClick() {
          var c;
          i.value.resetFields(), s("reset", {
            formRef: i,
            dialogRef: f,
            formModel: t,
            validate: (c = i.value) == null ? void 0 : c.validate,
            rawFormModel: h()
          });
        },
        children: (r = l.actionsConfig.resetText) != null ? r : "\u91CD\u7F6E"
      }, {
        el: "el-button",
        "v-if": l.actionsConfig.showCancel,
        onClick() {
          s("update:modelValue", !1), s("cancel");
        },
        children: (a = l.actionsConfig.cancelText) != null ? a : "\u53D6\u6D88"
      }];
      return (V = l.actionsConfig) != null && V.custom && (e = l.actionsConfig.custom(e)), b ? n(m, {
        list: e
      }, null) : j ? n(F, null, {
        default: () => [n(m, {
          list: e
        }, null)]
      }) : n(S, l.actionsConfig, {
        default: () => [n(F, null, {
          default: () => [n(m, {
            list: e
          }, null)]
        })]
      });
    }, i = O(), t = O(l.model), y = () => {
      t.value = {}, l.options.forEach((e) => {
        if (e.prop && typeof e.prop == "string") {
          const o = e.el === "el-upload" ? "fileList" : "modelValue";
          t.value[e.prop] = G(e, o);
        }
      });
    };
    y();
    const h = () => {
      const e = {};
      for (const o in t.value)
        e[o] = D(t.value[o]);
      return e;
    }, A = () => n(w("el-form"), p(g, {
      ref: i,
      model: t.value
    }), {
      default: () => [n(w("el-row"), g, {
        default: () => [E(l.options), l.showActions && !b && R()]
      })]
    }), E = (e) => e.map((o) => {
      if (o = D(o), Array.isArray(o))
        return E(o);
      o.el === "el-upload" && (o.fileList = t.value[o.prop], o["onUpdate:fileList"] = (a) => {
        Object.prototype.hasOwnProperty.call(t.value, o.prop) && (t.value[o.prop] = a);
      });
      let r = {
        ...v(o, Object.keys(S.props)),
        class: o.class ? `${o.class}__el-col` : "",
        el: "el-col",
        children: {
          ...v(o, Object.keys(F.props)),
          class: o.class ? `${o.class}__el-form-item` : "",
          el: "el-form-item",
          children: o
        }
      };
      return j && (r = r.children), o.el === "editor" && (r.children.children = B(o)), n(m, {
        model: t.value,
        list: r
      }, ne(u) ? u : {
        default: () => [u]
      });
    }), d = _({}), B = (e) => (e.prop && !d.value[e.prop] && (d.value[e.prop] = _()), n(H, null, [n(le, p({
      style: "border-bottom: 1px solid #ccc",
      mode: "default",
      editor: e.prop && d.value[e.prop].value
    }, e.editorAttrs), null), n(te, p({
      style: "height: 300px; width: 100%; overflow-y: hidden",
      mode: "default",
      modelValue: t.value[e.prop],
      "onUpdate:model-value": (o) => {
        Object.prototype.hasOwnProperty.call(t.value, e.prop) && (t.value[e.prop] = o);
      },
      onOnCreated: (o) => {
        e.prop && (d.value[e.prop].value = o);
      }
    }, e.toolbarAttrs), null)])), C = {
      initFormModel: y,
      getRawFormModel: h,
      setFormModel: async (e, {
        includes: o = [...l.options.map((a) => a.prop).filter((a) => a), "id"],
        exclude: r = []
      } = {}) => {
        e = ee(e);
        let a = o != null && o.length ? v(e, o) : e;
        r != null && r.length && (a = oe(a, r)), await K(), Object.assign(t.value, a);
      },
      getFormRef: () => i,
      getDialogRef: () => f,
      formModel: t
    }, M = async () => {
      await K(), Object.assign(C, i.value), Object.assign(C, f.value);
    };
    return q(M), z(() => l.modelValue, M), x(C), () => n("div", null, [b ? U() : A()]);
  }
});
export {
  pe as default
};
